@@ -37,6 +37,22 @@ class Client:
         except:
             logging.info('error connecting to server')
 
+    def get_dashboard_id(
+            self,
+            dashboard_name
+    ):
+        if self.status_connection:
+            with self.server_auth:
+                self.workbook_id = ''
+                all_datasource, all_pagination = self.server.workbooks.get()
+                for workbooks in all_datasource:
+                    if workbooks.name == dashboard_name:
+                        self.workbook_id = workbooks.id
+                        # self.workbook = self.server.workbooks.get_by_id(self.workbook_id)
+                        # logging.info([view.name for view in self.workbook.views])
+            if self.workbook_id == '':
+                    logging.info('Dashboard '+dashboard_name +' not found on server')
+
     def dashboard_refresh(
         self,
         dashboard_name
@@ -44,20 +60,41 @@ class Client:
         """
         start jobs extract refresh for dashboard
         """
-        if self.status_connection:
-            self.dashboard_name = dashboard_name
+        self.connect_to_server()
+        self.get_dashboard_id(dashboard_name)
+        if self.workbook_id != '':
             with self.server_auth:
-                workbook_id = ''
-                all_datasource, all_pagination = self.server.workbooks.get()
-                for workbooks in all_datasource:
-                    if workbooks.name == self.dashboard_name:
-                        workbook_id = workbooks.id
-                if workbook_id == '':
-                    logging.info('Dashboard '+dashboard_name +' not found on server')
-                else:
-                    try:
-                        result = self.server.workbooks.refresh(workbook_id)
-                        logging.info('Dashboard start updating on '+str(result.created_at))
-                    except:
-                        logging.info('Dashboard is already starting')
+                try:
+                    result = self.server.workbooks.refresh(self.workbook_id)
+                    logging.info('Dashboard start updating on '+str(result.created_at))
+                except:
+                    logging.info('Dashboard extract refresh is already starting')
+
+    def view_to_csv(
+            self,
+            dashboard_name,
+            view_name,
+            csv_path,
+    ):
+        """
+        export view to csv file
+        """
+        self.get_dashboard_id(dashboard_name)
+        self.connect_to_server()
+        is_found = False
+        if self.workbook_id != '':
+            with self.server_auth:
+                try:
+                    workbook = self.server.workbooks.get_by_id(self.workbook_id)
+                    for view in workbook.views:
+                        if view.name == view_name:
+                            self.server.views.populate_csv(view)
+                            with open(csv_path, 'wb') as f:
+                                f.write(b''.join(view.csv))
+                                logging.info('View ' + view_name + ' export to csv')
+                                is_found = True
+                    if is_found == False:
+                        logging.info('View ' + view_name +' not found in workbook '+dashboard_name)
+                except:
+                    logging.info('Error!')
 
